sccoda.util.result\_classes
===========================

.. automodule:: sccoda.util.result_classes

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      CAResult
      CAResultConverter
   
   

   
   
   